<?php

/**
 * arado functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package arado
 */
// short parth
define('ARADO_THEME_DRI', get_template_directory());
define('ARADO_FRAMEWORK_DRI', ARADO_THEME_DRI . '/framework/');


if (!function_exists('arado_setup')) :

    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function arado_setup() {
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on arado, use a find and replace
         * to change 'arado' to the name of your theme in all the template files.
         */
        load_theme_textdomain('arado', get_template_directory() . '/languages');

        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'primary' => esc_html__('Header Menu', 'arado'),
        ));

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ));

        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('arado_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support('custom-logo', array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        ));
    }

endif;
add_action('after_setup_theme', 'arado_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function arado_content_width() {
    // This variable is intended to be overruled from themes.
    // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
    // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
    $GLOBALS['content_width'] = apply_filters('arado_content_width', 650);
}

add_action('after_setup_theme', 'arado_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
if (!function_exists('arado_widgets_init')) {

    function arado_widgets_init() {
        register_sidebar(array(
            'name' => esc_html__('Blog SideBar', 'arado'),
            'id' => 'blog-widgets',
            'description' => esc_html__('Add widgets here.', 'arado'),
            'before_widget' => '<div class="sidebars-widget-area"><div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div></div>',
            'before_title' => '<div class="title-widget"><h2>',
            'after_title' => '</h2></div>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Footer Logo widgets', 'arado'),
            'id' => 'logo-widgets',
            'description' => esc_html__('Add widgets here.', 'arado'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Footer One widgets', 'arado'),
            'id' => 'footer-widgets-one',
            'description' => esc_html__('Add widgets here.', 'arado'),
            'before_widget' => '<div class="footer-single-content"><div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div></div>',
            'before_title' => '<div class="title"><h2 class="widget-title">',
            'after_title' => '</h2></div>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Footer Two widgets', 'arado'),
            'id' => 'footer-widgets-two',
            'description' => esc_html__('Add widgets here.', 'arado'),
            'before_widget' => '<div class="footer-single-content"><div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div></div>',
            'before_title' => '<div class="title"><h2 class="widget-title">',
            'after_title' => '</h2></div>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Footer Subscribe widgets', 'arado'),
            'id' => 'footer-widgets-subscribe',
            'description' => esc_html__('Add widgets here.', 'arado'),
            'before_widget' => '<div class="footer-single-content"><div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div></div>',
            'before_title' => '<div class="title"><h2 class="widget-title">',
            'after_title' => '</h2></div>',
        ));
    }

}
add_action('widgets_init', 'arado_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function arado_scripts() {

    wp_enqueue_style('bootstrap-grid', get_template_directory_uri() . '/assets/css/bootstrap-grid.min.css');
    wp_enqueue_style('arado-slinky', get_template_directory_uri() . '/assets/css/slinky.min.css');
    wp_enqueue_style('arado-iconic-font-style', get_template_directory_uri() . '/assets/css/material-design-iconic-font.min.css');
    wp_enqueue_style('swiper', get_template_directory_uri() . '/assets/css/swiper.min.css');
    wp_enqueue_style('light', get_template_directory_uri() . '/assets/css/light.css');
    wp_enqueue_style('arado-style', get_stylesheet_uri());

    wp_enqueue_script('arado-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true);
    wp_enqueue_script('arado-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true);
    wp_enqueue_script('plugins', get_template_directory_uri() . '/assets/js/plugins.js', array('jquery'), '20151215', true);
    wp_enqueue_script('arado-main', get_template_directory_uri() . '/assets/js/main-1.js', array('jquery'), '20151215', true);
    wp_enqueue_script('arado-script-hub', get_template_directory_uri() . '/assets/js/script-hub.js', array('jquery'), '20151215', true);

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}

add_action('wp_enqueue_scripts', 'arado_scripts');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
    require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Registers an editor stylesheet for the theme.
 */
function wpdocs_theme_add_editor_styles() {
    add_editor_style('editor-style.css');
}

add_action('admin_init', 'wpdocs_theme_add_editor_styles');

/**
 * / google font wp_enqueue_style
 * */
function arado_add_default_google_font() {
    wp_enqueue_style('arado-google-fonts', arado_default_google_font(), array(), NULL);
}

add_action('wp_enqueue_scripts', 'arado_add_default_google_font');

function arado_default_google_font() {
    $protocol = is_ssl() ? 'https:' : 'http:';
    $query_args = array(
        'family' => 'Karla:400,700',
    );
    $font_url = add_query_arg($query_args, $protocol . "//fonts.googleapis.com/css");
    return esc_url_raw($font_url);
}

/**
 * End google font wp_enqueue_style
 * */
function menu_add_class_li() {

    function add_classes_on_li($classes, $item, $args) {
        $classes[] = 'item-slide';
        return $classes;
    }

    add_filter('nav_menu_css_class', 'add_classes_on_li', 1, 3);
}

add_action('init', 'menu_add_class_li');

/**
 * Load WooCommerce compatibility file.
 */
/**
 * Load Svg Images
 */
if (class_exists('WooCommerce')) {
    require get_template_directory() . '/inc/woocommerce.php';
}

function add_svg_to_upload_mimes($upload_svg) {
    $upload_svg['svg'] = 'image/svg+xml';
    $upload_svg['svgz'] = 'image/svg+xml';
    return $upload_svg;
}

add_filter('upload_svg', 'add_svg_to_upload_svg', 10, 1);
/**
 * End Svg Images
 */
/**
 * Filter the except length to 20 words.
 *
 * @param int $length Excerpt length.
 * @return int (Maybe) modified excerpt length.
 */
if (!function_exists('arado_custom_excerpt_length')) {

    function arado_custom_excerpt_length($length) {
        return 10;
    }

}

add_filter('excerpt_length', 'arado_custom_excerpt_length', 999);
